'use strict';

var _babylon = require('babylon');

var babylon = _interopRequireWildcard(_babylon);

var _babelTypes = require('babel-types');

var types = _interopRequireWildcard(_babelTypes);

var _babelCore = require('babel-core');

var babel = _interopRequireWildcard(_babelCore);

var _babelTraverse = require('babel-traverse');

var _babelTraverse2 = _interopRequireDefault(_babelTraverse);

var _babelGenerator = require('babel-generator');

var _babelGenerator2 = _interopRequireDefault(_babelGenerator);

var _assert = require('./assert');

var _visitor = require('../visitor');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

describe('visitor', () => {
  describe('#default', () => {
    it('should insert the hot swap call to declarative modules', () => {
      const text = `
        import foo from './foo';
        export function bar() {}
        export const woz = 'woz';
      `;
      const ast = babylon.parse(text, { sourceType: 'module' });
      const visitor = (0, _visitor.createHotSwapVisitor)({ types: types }).visitor;
      (0, _babelTraverse2.default)(ast, visitor);
      const file = (0, _babelGenerator2.default)(ast, null, text);
      _assert.assert.equal(['module.hot.accept();', '', 'import foo from \'./foo\';', 'export function bar() {}', 'export const woz = \'woz\';'].join('\n'), file.code);
    });
    it('should not insert the hot swap call to non-declarative modules', () => {
      const text = 'setTimeout(() => {}, 0);';
      const ast = babylon.parse(text, { sourceType: 'module' });
      const visitor = (0, _visitor.createHotSwapVisitor)({ types: types }).visitor;
      (0, _babelTraverse2.default)(ast, visitor);
      const file = (0, _babelGenerator2.default)(ast, null, text);
      _assert.assert.equal('setTimeout(() => {}, 0);', file.code);
    });
    it('should place the call at the top of the file', () => {
      const text = `
        import foo from './foo';
        export function bar() {}
        export const woz = 'woz';
      `;
      const file = babel.transform(text, {
        plugins: [
        // We verify that our block hoist still functions when combined
        // with other plugins that use similar mechanisms
        'transform-es2015-modules-commonjs', require.resolve('..')]
      });
      const location = file.code.indexOf('\'use strict\';\n\nmodule.hot.accept();');
      _assert.assert.equal(location, 0);
    });
  });
  describe('#createHotSwapCall', () => {
    it('should generate nodes equivalent to a `module.hot.accept()` call', () => {
      const call = (0, _visitor.createHotSwapCall)(types);
      const ast = types.program([call]);
      const file = (0, _babelGenerator2.default)(ast);
      _assert.assert.equal(file.code, 'module.hot.accept();');
    });
    it('should ensure that the hot swap call is at the top of the file', () => {
      const call = (0, _visitor.createHotSwapCall)(types);
      _assert.assert.equal(call._blockHoist, Infinity);
    });
  });
});
//# sourceMappingURL=visitor.js.map